/*
 * @file 	bottoni_ats_003_up.pov
 * @desc	Bottoni con testo
 * @id		ATS
 * @ver 	1.0.1
 * @date	13/04/2004
 * @auth	Paolo Gibellini
 */
 

#version 3.5;

#include "colors.inc"
#include "shapes.inc"

global_settings {
  assumed_gamma 1.0
}

// ----------------------------------------
sky_sphere {
    pigment{ color rgb<0,0,0.15> }
}

light_source {
  <0, 0, 0>
  color rgb <1, 1, 1>
  translate <-20, 30, -30>
}
// ----------------------------------------

// Textures -------------------------------
#declare t_box_fast = texture {
    pigment{ color rgb<0.4,0.7,0.7> }
    finish { ambient 0.15 diffuse 0.7 phong 1}
}
#declare t_box_orange = texture {
    pigment { color rgb <1, 0.2, 0> }
    normal {
         crackle 1.8
         scale <.3,.3,.3>
    }
}
#declare t_box_yellow = texture {
    pigment { color rgb <1, 0.84, 0> }
    normal {
         crackle 1.8
         scale <.3,.3,.3>
    }
}
#declare t_box_blue = texture {
    pigment { color rgb <0.05, 0.05, 0.4> }
    normal {
         crackle 1.8
         scale <.3,.3,.3>
    }
}


#declare t_text_red = texture {
	pigment{ color rgb<1,0.2,0.2> }
	finish { specular 0.7 }
} 
#declare t_text_blue = texture {
    pigment { color rgb <0.05, 0.05, 0.4> }
	finish { specular 0.7 }
} 
#declare t_sphere_on = texture {
	pigment{ color rgb<0.1,0.9,0.2> }
	finish { specular 0.7 }
} 
#declare t_sphere_off = texture {
	pigment{ color rgb<1,0.2,0.2> }
} 
#declare t_sphere_over = texture {
	pigment{ color rgb<1,1,0.2> }
	finish { specular 0.7 }
}
/*
#declare alluminio_viola = texture {      
	pigment { color rgb <0.45098, 0.396078, 1.0>}      
	finish {
		ambient 0.1
		diffuse 0.65
		brilliance 1.5
		specular 0.85
		roughness 0.01
		reflection 0.45
	}
}
*/
#declare alluminio_viola = texture {      
	pigment { color rgb <0.8, 0.7, 1.0>}      
	finish {
		ambient 0.1
		diffuse 0.65
		brilliance 1.5
		specular 0.2
		roughness 0.01
		reflection 0.1
	}
}


#declare bronzo = texture {      
	pigment { color rgb <0.71, 0.65, 0.26> }      
	finish {
		ambient 0.2
		diffuse 0.7
		brilliance 6.0
		phong 0.75
		phong_size 80.0
		reflection 0.25
	}
}

#declare bronzo_viola = texture {      
	pigment { color rgb <0.8, 0.7, 1.0>}      
	finish {
		ambient 0.2
		diffuse 0.7
		brilliance 6.0
		phong 0.75
		phong_size 80.0
		reflection 0.25
	}
}

#declare bronzo_nobile = texture {      
	pigment { color rgb <0.55, 0.5, 0.45> }
	finish {
		ambient 0.2
		diffuse 0.7
		brilliance 6.0
		phong 0.75
		phong_size 80.0
		reflection 0.25
	}
}

// ----------------------------------------

// Camera ---------------------------------
camera {
    //angle 45
    //location  <0, 6, 0>
    location  <0, 22, -8>
    direction 1.5*z
    right     x*image_width/image_height
    look_at   <0.0, 0.0,  0.0>
}
// ----------------------------------------

  
// ----------------------------------------
/*
 * testo    Testo del bottone
 * stato    1   on (testo a filo del bottone, sferetta verde)
 *          2   off (testo in alto, sferetta rossa)
 *          3   over (testo a filo - potrebbe anche essere incassato, sferetta gialla)
 * base		Vettore con la posizione di base
 */
#macro bottone(testo,stato,base)
	// Parti dipendenti dall'input
    #switch(stato)
        #case(1)
        	#local t_sphere_local=t_sphere_on
        	#local text_position=<-1.2, 1.04, -0.2>;
        #break
        #case(2)
    		#local t_sphere_local=t_sphere_off
        	#local text_position=<-1.2, 1.2, -0.2>;
        #break
        #case(3)
        	#local t_sphere_local=t_sphere_over
        	#local text_position=<-1.2, 1.01, -0.2>;
        #break
    #end
	
	//
    object {
        Round_Box(<-1.4,0.5,-0.5>,<1.5,1,0.5>, 0.25 , 0)  
        texture{bronzo_nobile}
        translate base
    }
    text {
        ttf "stp_____.ttf", testo, 1, 0 
        texture {t_text_red}
        scale <.5,.5,.5>
        rotate <90, 0, 0>
        translate text_position
        translate base
    }
    sphere { <0, 1, 0>, 0.5 
        texture {t_sphere_local}
        scale <0.3,0.3,0.3>
        translate <1.4,0.6,0>
        translate base
    }
#end
// ----------------------------------------


bottone("HOME",2,<-7.5,0,0>)
bottone("ABOUT US",2,<-4.5,0,0>)
bottone("PARTNERS",2,<-1.5,0,0>)
bottone("LINKS",2,<1.5,0,0>)
bottone("CAREERS",2,<4.5,0,0>)
bottone("MAP",2,<7.5,0,0>)